@@ -14,30 +14,18 @@
 # Free Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 # MA  02111-1307  USA
 
-# Copyrights (C)
-# for this R-port: 
-#   1999 - 2008, Diethelm Wuertz, Rmetrics Foundation, GPL
-#  Diethelm Wuertz <wuertz@itp.phys.ethz.ch>
-#  info@rmetrics.org
-#  www.rmetrics.org
-# for the code accessed (or partly included) from other R-ports:
-#  see R's copyright and license files
-# for the code accessed (or partly included) from contributed R-ports
-# and other sources
-#  see Rmetrics's copyright file
 
-
-################################################################################
+###########################\#####################################################
 
 
 test.Fit <- 
     function()
 {   
     # Simulate Artificial LM:
-    x = as.timeSeries(data(LPP2005REC))
+    x <- as.timeSeries(data(LPP2005REC))
     
     # Fit Parameters:
-    lmfit = regFit(LPP40 ~ 0 + SPI + SBI + SII + LMI + MPI + ALT, 
+    lmfit <- regFit(LPP40 ~ 0 + SPI + SBI + SII + LMI + MPI + ALT, 
         data = x, use = "lm") 
     
     # 
@@ -48,5 +36,6 @@ test.Fit <-
 }
 
 
-################################################################################
+###############################################################################
+
 
